summaryrefslogtreecommitdiffstats
path: root/konq-plugins/babelfish
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 21:01:57 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 21:01:57 -0600
commita5a7573f3597f76e3cf9ebfb5a38416906289ff3 (patch)
treebeabf7411b6bfeb386bea8016fa48eebf61db192 /konq-plugins/babelfish
parentf21b0182707822a0aeaedd00578eb18ce191c47d (diff)
downloadtdeaddons-a5a7573f3597f76e3cf9ebfb5a38416906289ff3.tar.gz
tdeaddons-a5a7573f3597f76e3cf9ebfb5a38416906289ff3.zip
Rename kiobuffer and KHTML
Diffstat (limited to 'konq-plugins/babelfish')
-rw-r--r--konq-plugins/babelfish/Makefile.am2
-rw-r--r--konq-plugins/babelfish/plugin_babelfish.cpp10
2 files changed, 6 insertions, 6 deletions
diff --git a/konq-plugins/babelfish/Makefile.am b/konq-plugins/babelfish/Makefile.am
index 61eba5b..82cf1e0 100644
--- a/konq-plugins/babelfish/Makefile.am
+++ b/konq-plugins/babelfish/Makefile.am
@@ -5,7 +5,7 @@ METASOURCES = AUTO
kde_module_LTLIBRARIES = libbabelfishplugin.la
libbabelfishplugin_la_SOURCES = plugin_babelfish.cpp
-libbabelfishplugin_la_LIBADD = $(LIB_KPARTS) $(LIB_KHTML)
+libbabelfishplugin_la_LIBADD = $(LIB_KPARTS) $(LIB_TDEHTML)
libbabelfishplugin_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries) -no-undefined
pluginsdir = $(kde_datadir)/tdehtml/kpartplugins
diff --git a/konq-plugins/babelfish/plugin_babelfish.cpp b/konq-plugins/babelfish/plugin_babelfish.cpp
index 0cd4a54..a575396 100644
--- a/konq-plugins/babelfish/plugin_babelfish.cpp
+++ b/konq-plugins/babelfish/plugin_babelfish.cpp
@@ -178,7 +178,7 @@ PluginBabelFish::PluginBabelFish( TQObject* parent, const char* name,
m_menu->setEnabled( true );
// TODO: we could also support plain text viewers...
- if ( parent && parent->inherits( "KHTMLPart" ) )
+ if ( parent && parent->inherits( "TDEHTMLPart" ) )
{
KParts::ReadOnlyPart* part = static_cast<KParts::ReadOnlyPart *>(parent);
connect( part, TQT_SIGNAL(started(TDEIO::Job*)), this,
@@ -193,7 +193,7 @@ PluginBabelFish::~PluginBabelFish()
void PluginBabelFish::slotStarted( TDEIO::Job* )
{
- if ( parent()->inherits("KHTMLPart") &&
+ if ( parent()->inherits("TDEHTMLPart") &&
// Babelfish wants http URLs only. No https.
static_cast<KParts::ReadOnlyPart *>(parent())->url().protocol().lower() == "http" )
{
@@ -211,8 +211,8 @@ void PluginBabelFish::translateURL()
if ( !sender() )
return;
- // The parent is assumed to be a KHTMLPart
- if ( !parent()->inherits("KHTMLPart") )
+ // The parent is assumed to be a TDEHTMLPart
+ if ( !parent()->inherits("TDEHTMLPart") )
{
TQString title = i18n( "Cannot Translate Source" );
TQString text = i18n( "Only web pages can be translated using "
@@ -227,7 +227,7 @@ void PluginBabelFish::translateURL()
TQString engine = cfg.readEntry( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name(), "babelfish" );
// Get URL
- KHTMLPart *part = dynamic_cast<KHTMLPart *>(parent());
+ TDEHTMLPart *part = dynamic_cast<TDEHTMLPart *>(parent());
if ( !part )
return;